==> webgen-0.1.tgz: webgen-0.1/process.php <==
<?php 
 require("config.php");
 require("dbconfig.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="process.php";
  //TableXSOѼ
 $tabout="border=1";
  //d߳浧ƪY
  //C@
 $PGNUM=20;
 // Primary Key	
 $PKEY="aid";
 $RETADD="maintain.html";
 /***** {ҥΨ **********/
 require("auth.php");
 $DAYTIME=date("Y~mdH:i:s");
  /****BzJܼ*****/
  if (get_magic_quotes_gpc()==0)
  {
	$ptab=addslashes($ptab);
	$pname=addslashes($pname);
	$ctlfile=addslashes($ctlfile);
	$target=addslashes($target);
  }
  //INSERTO
  $INSERT="insert into main values ('$ptab','$pname','$ctlfile','$target','$PHP_AUTH_USER','$REMOTE_ADDR','$DAYTIME')"; 
  //DELETEO
 $LIMIT=stripslashes($LIMIT);
 $DELETE="delete from main where ".$LIMIT;
 if (strcmp($process,"sW")==0) // insert
 {
   if ($dodel==1) //ݭnR
   	{
		$result=db_exec($db_conn,$DELETE);
		if (!$result){
			echo "ƧR~AO $DELETE !";
			exit;
		}
	}
   
   $result=db_exec($db_conn,$INSERT);
   if (!$result){
	echo "ƷsW~AO $INSERT !";
	exit;
   }
  if ($dodel==0) //Ĥ@sW
  {
   /****} ******/
   $PRJ=join( "", file( "prj.cfg" ) );
   $PRJ=str_replace("%name%",$ptab,$PRJ);
   for ($i=0;$i<count($MANAGER);$i++)
       $PRJ=$PRJ." grant all on $ptab to $MANAGER[$i];";
   echo "PRJ=$PRJ<br>";
   $result=db_exec($db_conn,$PRJ);
   if (!$result){
	echo "MƷsW~AO $PRJ !";
	exit;
   }
   /*******]max()BzsbƩҥH....********/
   /***************
   $IFIRST="insert into $ptab values (0,'','','','','','','','','')";
   $result=db_exec($db_conn,$IFIRST);
   if (!$result){
	echo "MlƷsW~AO $IFIRST !";
	exit;
   }
   ****************/
   /******إߥؿ******/
   if (!mkdir($BASEDIR.$target,0755))
   	{
	  echo "}ұMؿ~AؿWrO $BASEDIR$target!";
	  exit;
	}
   }
	echo "<a href=\"$RETADD\">J\IB}I</a>\n";
 	exit;
 }
 /*****  R ********/
 if (strcmp($process,"R")==0) //DELETE 
 {
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
	echo "ƧR~AO $DELETE !";
	exit;
   }
	echo "<a href=\"$RETADD\">R\IB}I</a>\n";
        exit;
 }
 /*****  ק ********/
 $LIMIT="ptab='$key'";
 $EDIT="select ptab,pname,ctlfile,target from main where ".$LIMIT;
 if (strcmp($process,"ק")==0) //EDIT 
 {
   $result=db_exec($db_conn,$EDIT);
   if (!$result){
	echo "ƭק~AO $EDIT !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   /****} ******/
   $fcfg=fopen("main.cfg","r");
   $cnt=0;
   $PAT="%DATA";
   while (!feof($fcfg)) 
      {
         $temp=fgets($fcfg,256);
 	 if (strstr($temp,$PAT))
         {
		$temp=str_replace($PAT,$ARAW[$cnt],$temp);
		$cnt=$cnt+1;
	 } elseif (strstr($temp,"%LIMIT"))
	 {
		$temp=str_replace("%LIMIT","<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">",$temp);
	 }
	 echo $temp;
      }
   fclose($fcfg);
        exit;
 }
?>

==> webgen-0.2.tgz: webgen-0.2/process.php <==
<?php 
 require("config.php");
 require("dbconfig.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="process.php";
  //TableXSOѼ
 $tabout="border=1";
  //d߳浧ƪY
  //C@
 $PGNUM=20;
 // Primary Key	
 $PKEY="aid";
 $RETADD="maintain.html";
 /***** {ҥΨ **********/
 require("auth.php");
 $DAYTIME=date("Y~mdH:i:s");
  /****BzJܼ*****/
  if (get_magic_quotes_gpc()==0)
  {
	$ptab=addslashes($ptab);
	$pname=addslashes($pname);
	$ctlfile=addslashes($ctlfile);
	$target=addslashes($target);
  }
  //INSERTO
  $INSERT="insert into main values ('$ptab','$pname','$ctlfile','$target','$PHP_AUTH_USER','$REMOTE_ADDR','$DAYTIME')"; 
  //DELETEO
 $LIMIT=stripslashes($LIMIT);
 $DELETE="delete from main where ".$LIMIT;
 if (strcmp($process,"sW")==0) // insert
 {
   if ($dodel==1) //ݭnR
   	{
		$result=db_exec($db_conn,$DELETE);
		if (!$result){
			echo "ƧR~AO $DELETE !";
			exit;
		}
	}
   
   $result=db_exec($db_conn,$INSERT);
   if (!$result){
	echo "ƷsW~AO $INSERT !";
	exit;
   }
  if ($dodel==0) //Ĥ@sW
  {
   /****} ******/
   $PRJ=join( "", file( "prj.cfg" ) );
   $PRJ=str_replace("%name%",$ptab,$PRJ);
   for ($i=0;$i<count($MANAGER);$i++)
       $PRJ=$PRJ." grant all on $ptab to $MANAGER[$i];";
   //echo "PRJ=$PRJ<br>";
   $result=db_exec($db_conn,$PRJ);
   if (!$result){
	echo "MƷsW~AO $PRJ !";
	exit;
   }
   /******إߥؿ******/
   if (!mkdir($BASEDIR.$target,0755))
   	{
	  echo "}ұMؿ~AؿWrO $BASEDIR$target!";
	  exit;
	}
   }
	echo "<a href=\"$RETADD\">J\IB}I</a>\n";
 	exit;
 }
 /*****  R ********/
 if (strcmp($process,"R")==0) //DELETE
 {
   $LIMIT="ptab='$key'";
   $DELETE="delete from main where ".$LIMIT;
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
        echo "ƧR~AO $DELETE !<br>\n";
        exit;
   }
   $DELETE="drop table $key";
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
        echo "ƧR~AO $DELETE !<br>\n";
        exit;
   }
        echo "<a href=\"$RETADD\">R\IB}I</a><br>\n";
        exit;
 }
 /*****  ק ********/
 $LIMIT="ptab='$key'";
 $EDIT="select ptab,pname,ctlfile,target from main where ".$LIMIT;
 if (strcmp($process,"ק")==0) //EDIT 
 {
   $result=db_exec($db_conn,$EDIT);
   if (!$result){
	echo "ƭק~AO $EDIT !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   /****} ******/
   $fcfg=fopen("main.cfg","r");
   $cnt=0;
   $PAT="%DATA";
   while (!feof($fcfg)) 
      {
         $temp=fgets($fcfg,256);
 	 if (strstr($temp,$PAT))
         {
		$temp=str_replace($PAT,$ARAW[$cnt],$temp);
		$cnt=$cnt+1;
	 } elseif (strstr($temp,"%LIMIT"))
	 {
		$temp=str_replace("%LIMIT","<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">",$temp);
	 }
	 echo $temp;
      }
   fclose($fcfg);
        exit;
 }
?>
